@@ -8,6 +8,7 @@ from torch_geometric.utils.convert import from_networkx
 from bpemb import BPEmb
 from sentence_transformers import SentenceTransformer
 from graphmanagerlib.Graph import Grapher
+from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects
 
 bpemb_en = BPEmb(lang="en", dim=100)
 sent_model = SentenceTransformer('distilbert-base-nli-stsb-mean-tokens')
@@ -97,22 +98,16 @@ def makeIndividualData(file):
     print(f'File {file.index} --> Success')
     return individual_data
 
-def getDataForUniquePrediction(source_fd,save_fd):
-    path = source_fd
-    files = [i.split('.')[0] for i in os.listdir(path)]
-    files.sort()
-    all_files = files[0:]
+def getDataForUniquePrediction(json,save_fd):
     test_list_of_graphs = []
-
-    data_fd = "C:/AsianGCN/prediction"
-    for file in all_files:
-        individual_data = makeIndividualData(file, data_fd)
-        test_list_of_graphs.append(individual_data)
-
+    jsonAsDoc = ConvertJsonToDocumentsObjects(json)[0]
+    individual_data = makeIndividualData(jsonAsDoc)
+    test_list_of_graphs.append(individual_data)
     test_data = torch_geometric.data.Batch.from_data_list(test_list_of_graphs)
     test_data.edge_attr = None
-
-    torch.save(test_data, os.path.join(save_fd, 'predictions_data.dataset'))
+    saved_path = os.path.join(save_fd, 'predictions_data.dataset')
+    torch.save(test_data, saved_path)
+    return saved_path
 
 def load_train_test_split(save_fd):
     train_data = torch.load(os.path.join(save_fd, 'train_data.dataset'))
