@@ -4,14 +4,10 @@ from graphmanagerlib.Inference import predictionsUnique
 
 
 class GraphManager:
-    def __init__(self, documents, save_dataset_fd,nb_classes):
-        self.save_dataset_path = save_dataset_fd
-        self.nb_classes = nb_classes
+    def CreateTrainAndSaveGCN(self,documents, save_dataset_fd,nb_classes):
         get_data(documents=documents, save_dataset_fd=save_dataset_fd)
-
-    def CreateTrainAndSaveGCN(self):
-        traindata, testdata = load_train_test_split(self.save_dataset_path)
-        CreateTrainAndSaveGCN(traindata, testdata, self.save_dataset_path, self.nb_classes)
+        traindata, testdata = load_train_test_split(save_dataset_fd)
+        CreateTrainAndSaveGCN(traindata, testdata,save_dataset_fd, nb_classes)
         print("===== Modèle entrainé et sauvegardé =====")
 
     def single_prediction(self, saved_model_folder,document_to_predict_json, labels_tab):
