@@ -22,7 +22,7 @@ def make_info(document):
     return G, df, individual_data
 
 def predictionsUnique(saved_model_folder, document_to_predict_json,labels_tab):
-    prediction_dataset_folder = getDataForUniquePrediction(document_to_predict_json)
+    prediction_dataset_folder = getDataForUniquePrediction(document_to_predict_json, saved_model_folder)
 
     predictions_data = load_predictionData(save_fd=prediction_dataset_folder)
 
